import { IsNotEmpty, IsString, IsEnum, Matches } from 'class-validator';

/**
 * DTO for creating a new tag
 */
export class CreateTagDto {
  /**
   * The name of the tag
   */
  @IsNotEmpty()
  @IsString()
  name: string;

  /**
   * The color of the tag (hex format)
   */
  @IsNotEmpty()
  @IsString()
  @Matches(/^#[0-9A-Fa-f]{6}$/, {
    message: 'Color must be a valid hex color code (e.g., #FF5733)',
  })
  color: string;

  /**
   * The type of the tag (PROJECT or PERSON)
   */
  @IsNotEmpty()
  @IsEnum(['PROJECT', 'PERSON'], {
    message: 'Type must be either PROJECT or PERSON',
  })
  type: 'PROJECT' | 'PERSON';
}