import { Injectable } from '@nestjs/common';
import { WebSocketsGateway } from './websockets.gateway';

/**
 * WebSocketsService
 * 
 * This service provides methods for other services to emit WebSocket events.
 * It acts as a facade for the WebSocketsGateway.
 */
@Injectable()
export class WebSocketsService {
  constructor(private readonly websocketsGateway: WebSocketsGateway) {}

  /**
   * Emit project updated event
   */
  emitProjectUpdated(projectId: string, data: any) {
    this.websocketsGateway.emitProjectUpdated(projectId, data);
  }

  /**
   * Emit collaborator added event
   */
  emitCollaboratorAdded(projectId: string, data: any) {
    this.websocketsGateway.emitCollaboratorAdded(projectId, data);
  }

  /**
   * Emit group created event
   */
  emitGroupCreated(projectId: string, data: any) {
    this.websocketsGateway.emitGroupCreated(projectId, data);
  }

  /**
   * Emit group updated event
   */
  emitGroupUpdated(projectId: string, data: any) {
    this.websocketsGateway.emitGroupUpdated(projectId, data);
  }

  /**
   * Emit person added to group event
   */
  emitPersonAddedToGroup(projectId: string, data: any) {
    this.websocketsGateway.emitPersonAddedToGroup(projectId, data);
  }

  /**
   * Emit person removed from group event
   */
  emitPersonRemovedFromGroup(projectId: string, data: any) {
    this.websocketsGateway.emitPersonRemovedFromGroup(projectId, data);
  }

  /**
   * Emit notification to a specific user
   */
  emitNotification(userId: string, data: any) {
    this.websocketsGateway.emitNotification(userId, data);
  }

  /**
   * Emit notification to all users in a project
   */
  emitProjectNotification(projectId: string, data: any) {
    this.websocketsGateway.emitProjectNotification(projectId, data);
  }
}