"use client";

import { useState } from "react";
import Link from "next/link";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { ArrowLeft } from "lucide-react";
import { TagSelector, Tag } from "@/components/tag-selector";
import { Label } from "@/components/ui/label";

export default function TagSelectorDemoPage() {
  const [selectedTags, setSelectedTags] = useState<Tag[]>([]);

  return (
    <div className="flex flex-col gap-6">
      <div className="flex items-center gap-2">
        <Button variant="outline" size="icon" asChild>
          <Link href="/tags">
            <ArrowLeft className="h-4 w-4" />
          </Link>
        </Button>
        <h1 className="text-3xl font-bold">Démo du Sélecteur de Tags</h1>
      </div>

      <div className="grid gap-6 md:grid-cols-2">
        <Card>
          <CardHeader>
            <CardTitle>Sélecteur de Tags</CardTitle>
            <CardDescription>
              Un composant réutilisable pour sélectionner plusieurs tags
            </CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <div className="space-y-2">
              <Label htmlFor="tags">Tags</Label>
              <TagSelector
                selectedTags={selectedTags}
                onChange={setSelectedTags}
                placeholder="Sélectionner des tags..."
              />
            </div>
          </CardContent>
          <CardFooter>
            <p className="text-sm text-muted-foreground">
              {selectedTags.length > 0
                ? `${selectedTags.length} tag${selectedTags.length > 1 ? "s" : ""} sélectionné${selectedTags.length > 1 ? "s" : ""}`
                : "Aucun tag sélectionné"}
            </p>
          </CardFooter>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle>Utilisation dans un formulaire</CardTitle>
            <CardDescription>
              Comment utiliser le sélecteur de tags dans un formulaire
            </CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <div className="rounded-md bg-muted p-4">
              <pre className="text-xs overflow-auto">
{`// Importer le composant
import { TagSelector, Tag } from "@/components/tag-selector";

// Définir l'état pour les tags sélectionnés
const [selectedTags, setSelectedTags] = useState<Tag[]>([]);

// Utiliser le composant dans le formulaire
<div className="space-y-2">
  <Label htmlFor="tags">Tags</Label>
  <TagSelector
    selectedTags={selectedTags}
    onChange={setSelectedTags}
    placeholder="Sélectionner des tags..."
  />
</div>

// Accéder aux tags sélectionnés
console.log(selectedTags);
`}
              </pre>
            </div>
          </CardContent>
          <CardFooter>
            <div className="space-y-2 w-full">
              <Label>Tags sélectionnés (données)</Label>
              <div className="rounded-md bg-muted p-4 w-full overflow-auto">
                <pre className="text-xs">
                  {JSON.stringify(selectedTags, null, 2)}
                </pre>
              </div>
            </div>
          </CardFooter>
        </Card>
      </div>

      <Card>
        <CardHeader>
          <CardTitle>Exemple d'intégration</CardTitle>
          <CardDescription>
            Comment le sélecteur de tags peut être intégré dans différents formulaires
          </CardDescription>
        </CardHeader>
        <CardContent className="space-y-4">
          <div className="space-y-2">
            <h3 className="text-lg font-medium">Formulaire de création de personne</h3>
            <p className="text-sm text-muted-foreground">
              Le sélecteur de tags peut être utilisé pour attribuer des compétences ou des caractéristiques à une personne.
            </p>
            <div className="rounded-md bg-muted p-4">
              <pre className="text-xs overflow-auto">
{`// Dans le formulaire de création de personne
<div className="space-y-4">
  <div className="space-y-2">
    <Label htmlFor="name">Nom</Label>
    <Input id="name" placeholder="John Doe" />
  </div>
  
  <div className="space-y-2">
    <Label htmlFor="email">Email</Label>
    <Input id="email" type="email" placeholder="john.doe@example.com" />
  </div>
  
  <div className="space-y-2">
    <Label htmlFor="tags">Compétences / Caractéristiques</Label>
    <TagSelector
      selectedTags={selectedTags}
      onChange={setSelectedTags}
      placeholder="Sélectionner des compétences..."
    />
  </div>
</div>`}
              </pre>
            </div>
          </div>

          <div className="space-y-2">
            <h3 className="text-lg font-medium">Formulaire de création de projet</h3>
            <p className="text-sm text-muted-foreground">
              Le sélecteur de tags peut être utilisé pour catégoriser un projet.
            </p>
            <div className="rounded-md bg-muted p-4">
              <pre className="text-xs overflow-auto">
{`// Dans le formulaire de création de projet
<div className="space-y-4">
  <div className="space-y-2">
    <Label htmlFor="name">Nom du projet</Label>
    <Input id="name" placeholder="Projet Formation Dev Web" />
  </div>
  
  <div className="space-y-2">
    <Label htmlFor="description">Description</Label>
    <Textarea id="description" placeholder="Description du projet..." />
  </div>
  
  <div className="space-y-2">
    <Label htmlFor="tags">Catégories</Label>
    <TagSelector
      selectedTags={selectedTags}
      onChange={setSelectedTags}
      placeholder="Sélectionner des catégories..."
    />
  </div>
</div>`}
              </pre>
            </div>
          </div>
        </CardContent>
      </Card>
    </div>
  );
}